@@ -5,6 +5,10 @@ from .eth_module import (  # noqa: F401
 from .go_ethereum_admin_module import (  # noqa: F401
     GoEthereumAdminModuleTest,
 )
+from .go_ethereum_txpool_module import (  # noqa: F401
+    GoEthereumAsyncTxPoolModuleTest,
+    GoEthereumTxPoolModuleTest
+)
 from .net_module import (  # noqa: F401
     AsyncNetModuleTest,
     NetModuleTest,
